/*

Title:    AndyPi Pass the Parcel for Arduino Nano
Code by:  Andrew Wilsion http://andypi.co.uk
Date:     25-12-2014
Version:  1.0

Hardware: 
WS2801 pixel strip: connected to Data Pin and Clock Pin 
Push to make button switch: connected to button pin & GND
Potentiometer controls speed of colour swirl change: connected to analogue pin 

Libraries:
FastlED is the library used to control the LEDS, see here for reference:
https://github.com/FastLED/FastLED/wiki/Pixel-reference

*/

#include "FastLED.h"        // include the FastLED library
#define NUM_LEDS 18         // Define the number of LEDs in the strip
#define MAX_BRIGHTNESS 255  // Define maixmum brightness of the LEDS (0-255)
CRGB leds[NUM_LEDS];        // Define the array of leds
const int buttonPin = 2;    // set constant - pushbutton pin number (Digital pin 2)
int val = 0;                // variable to store the value coming from the potentiometer   
int buttonState;            // variable to hold the button state
int random_time;            // variable to hold the random number
unsigned long startTime;    // variable to hold start time

// Define the the digital pin number you attach the WS2801 to on the arduino (13 and 11)
#define DATA_PIN 13
#define CLOCK_PIN 11


void setup() { 
            
      FastLED.addLeds<WS2801, RGB>(leds, NUM_LEDS); // FastLED initialisation using WS2801 chip
      pinMode(buttonPin, INPUT_PULLUP);   // initialize the pushbutton pin as an input:pinMode(2, INPUT_PULLUP);
      randomSeed(analogRead(0)); // randomize
}


void loop()
{

// 1. Find random time between 5 and 25 seconds and set the start time for the couter
random_time=random(6,45);     
startTime=millis();          

// 2. Set a rainbow until the random delay has elapsed
while(((millis()-startTime)/1000) < random_time) 
  {
     rainbow(5);
  }

// 3.  Set all LEDs to white and then off
for(int led_number = 0; led_number < NUM_LEDS; led_number++)
    {
      leds[led_number].setHSV(255, 0, 255);  
    }
    FastLED.show();
    delay(1000);
for(int led_number = 0; led_number < NUM_LEDS; led_number++)
    {
      leds[led_number].setHSV(255, 0, 0);  
    }
    FastLED.show();
    
 
// 4. Wait until pushbutton is pressed for reset.
buttonState = HIGH;
while(buttonState==HIGH)
   {
      buttonState = digitalRead(buttonPin);
   }

 
}



void rainbow(uint8_t wait) // rainbow function
{

	uint16_t hue;
	FastLED.clear();

	for(hue=10; hue<255*3; hue++) 
	{

		fill_rainbow( &(leds[0]), NUM_LEDS /*led count*/, hue /*starting hue*/);		
		FastLED.show();
		delay(wait);
	}
	return;
}

